using System;
using System.Collections.Generic;
using System.Text;
using System.Data;

namespace CustomerWinCSharp
{
/// <summary>
/// Manages a single item purchased by a customer
/// </summary>
/// <remarks></remarks>
    class PurchasedItem
    {
        
#region  Properties
        private Int32 _ItemID;
        /// <summary>
        /// Primary key of the item
        /// </summary>
        /// <value></value>
        /// <returns>Item ID</returns>
        /// <remarks></remarks>
	    public Int32 ItemID
	    {
		    get { return _ItemID;}
		    set { _ItemID = value;}
	    }
	
        private string _ItemName;
        /// <summary>
        /// Name of the item
        /// </summary>
        /// <value></value>
        /// <returns>Item name</returns>
        /// <remarks></remarks>
	    public string ItemName
	    {
		    get { return _ItemName;}
		    set { _ItemName = value;}
	    }
	
        private string _Description;
    /// <summary>
        /// Description of the item
        /// </summary>
        /// <value></value>
        /// <returns>Item description</returns>
        /// <remarks></remarks>
	    public string Description
	    {
		    get { return _Description;}
		    set { _Description = value;}
	    }

        private Int32 _CustomerID;
        /// <summary>
        /// ID of the Customer who purchased this item
        /// </summary>
        /// <value></value>
        /// <returns>Customer ID</returns>
        /// <remarks></remarks>
	    public Int32 CustomerID
	    {
		    get { return _CustomerID;}
		    private set { _CustomerID = value;}
	    }
	

        private Customer _CustomerInstance;
        /// <summary>
        /// Instance defining the customer who purchased this item
        /// </summary>
        /// <value></value>
        /// <returns>Customer instance</returns>
        /// <remarks>This property is read-only</remarks>
	    public Customer CustomerInstance
	    {
		    get 
            { 
                if (_CustomerInstance==null)
	            {
            		 _CustomerInstance = Customer.Create(CustomerID);
	            }
                return _CustomerInstance;
            }
	    }
#endregion

#region Public Methods

#region Create
    /// <summary>
    /// Creates an instance of the class
    /// </summary>
    /// <param name="dr">DataRow containing the data to populate the instance</param>
    /// <returns>Fully populated PurchasedItem instance</returns>
    /// <remarks></remarks>
    public static PurchasedItem Create(DataRow dr )
    {
        PurchasedItem oItem = new PurchasedItem();

        // Populate the object
        oItem.ItemID = Convert.ToInt32(dr["ItemID"]);
        oItem.ItemName = dr["ItemName"].ToString();
        oItem.Description = dr["Description"].ToString();
        oItem.CustomerID =  Convert.ToInt32(dr["CustomerID"]);

        return oItem;
    }
#endregion

#endregion

    }
}
