''' <summary>
''' Manages the read-only list of customers for display and selection
''' </summary>
''' <remarks>This is an example of "fake" object binding that actually binds
''' to a data table</remarks>
Public Class CustomerList

#Region " Properties"
    ''' <summary>
    ''' Full name of the customer
    ''' </summary>
    ''' <value></value>
    ''' <returns>Customer's full name</returns>
    ''' <remarks>This is the display member</remarks>
    Public ReadOnly Property FullName() As String
        Get
            Return ""
        End Get
    End Property

    ''' <summary>
    ''' ID of the customer
    ''' </summary>
    ''' <value></value>
    ''' <returns>Customer ID</returns>
    ''' <remarks>This is the value member</remarks>
    Public ReadOnly Property CustomerID() As Int32
        Get
            Return 0
        End Get
    End Property

    ''' <summary>
    ''' DataTable containing the customer list data
    ''' </summary>
    ''' <value></value>
    ''' <returns>Customer DataTable</returns>
    ''' <remarks>The list is bound to this DataTable</remarks>
    Public ReadOnly Property CustomerDataTable() As DataTable
        Get
            Return Retrieve()
        End Get
    End Property
#End Region

#Region " Private Methods"

#Region " Retrieve"
    ''' <summary>
    ''' Retrieves the DataTable using the appropriate mechanism
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>In a real application, this would call a data access component,
    ''' access a typed dataset or TableAdapter, or call a Web service.</remarks>
    Private Function Retrieve() As DataTable
        Dim dt As New DataTable

        dt.Columns.Add("FullName")
        dt.Columns.Add("CustomerID")

        dt.Rows.Add("Einstein, Albert", 1)
        dt.Rows.Add("Curie, Marie", 2)
        dt.Rows.Add("Brahe, Tycho", 3)
        dt.Rows.Add("Faraday, Michael", 4)

        Return dt
    End Function
#End Region

#End Region

End Class
