''' <summary>
''' Manages the collection of items purchased by a single customer
''' </summary>
''' <remarks></remarks>
Public Class PurchasedItemCollection : Inherits System.ComponentModel.BindingList(Of PurchasedItem)

#Region " Public Methods"

#Region " Create"
    ''' <summary>
    ''' Creates an instance of this collection populated with all items purchased
    ''' by the defined customer
    ''' </summary>
    ''' <param name="CustomerID">ID of the customer</param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Shared Function Create(ByVal CustomerID As Int32) As PurchasedItemCollection
        Dim oCollection As New PurchasedItemCollection
        Dim dt As DataTable

        ' Perform the appropriate retrieve
        dt = oCollection.Retrieve(CustomerID)

        ' For each row, create an object in the list
        For Each dr As DataRow In dt.Rows
            Dim oItem As PurchasedItem
            oItem = PurchasedItem.Create(dr)

            oCollection.Add(oItem)
        Next

        Return oCollection
    End Function
#End Region

#End Region

#Region " Private Methods"

#Region " Retrieve"

    ''' <summary>
    ''' Retrieves the PurchasedItem data using the appropriate mechanism
    ''' </summary>
    ''' <param name="CustomerID">ID of the customer for which PurchasedItems
    ''' are to be retrieved</param>
    ''' <returns></returns>
    ''' <remarks>In a real application, this would call a data access component,
    ''' access a typed dataset or TableAdapter, or call a Web service.</remarks>
    Private Function Retrieve(ByVal CustomerID As Int32) As DataTable
        Dim dt As New DataTable

        ' Define the columns
        dt.Columns.Add("ItemID")
        dt.Columns.Add("ItemName")
        dt.Columns.Add("Description")
        dt.Columns.Add("CustomerID")

        ' Test data
        Select Case CustomerID
            Case 1
                dt.Rows.Add(1, "Accelerator", "Linear particle accelerator", 1)
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 1)
                dt.Rows.Add(3, "Telescope", "Night vision telescope", 1)
                dt.Rows.Add(4, "Table", "Periodic table of elements", 1)

            Case 2
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 2)
                dt.Rows.Add(4, "Table", "Periodic table of elements", 2)

            Case 3
                dt.Rows.Add(3, "Telescope", "Night vision telescope", 2)

            Case 4
                dt.Rows.Add(1, "Accelerator", "Linear particle accelerator", 3)
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 3)
                dt.Rows.Add(4, "Table", "Periodic table of elements", 3)

        End Select

        Return dt
    End Function
#End Region

#End Region

End Class
